@@ -1,5 +1,6 @@
 from pequod_cli.auth import AuthService
 from pequod_cli.controller import ClusterController
+from pequod_cli.lbupdater.service import Lbupdater
 from pequod_cli.manager import CoreManager
 from pequod_cli.registry import ApplicationRegistry
 from pequod_cli.replicator import FileReplicator
@@ -16,5 +17,6 @@ class Context:
         self.manager = CoreManager(endpoints, credentials, cacert)
         self.registry = ApplicationRegistry(endpoints, credentials, cacert)
         self.controller = ClusterController(endpoints, credentials, cacert)
+        self.lbupdater = Lbupdater(endpoints, credentials, cacert)
 
-        self.all_core_services = [self.auth, self.replicator, self.manager, self.registry, self.controller]
+        self.all_services = [self.auth, self.replicator, self.manager, self.registry, self.controller, self.lbupdater]
