@@ -8,9 +8,10 @@ from pequod_cli.lbupdater.cli import lbupdater
 from pequod_cli.manager.cli import manager
 from pequod_cli.registry.cli import registry
 from pequod_cli.replicator.cli import replicator
-from pequod_cli.service import CORE_DOMAINS
+from pequod_cli.service import CORE_DOMAINS, CORE_PORTS, format_ip
 from pequod_cli.utils import AliasedGroup, generate_help_tree, find_cacert_bundle
 import click
+import ipaddress
 import logging
 import os
 import requests
@@ -83,6 +84,14 @@ Please use the "login" command or edit the configuration file {} manually.'''.fo
 class Endpoints(click.ParamType):
     name = 'Endpoints'
 
+    @staticmethod
+    def is_ip(s):
+        try:
+            ipaddress.ip_address(s)
+            return True
+        except:
+            return False
+
     def convert(self, value, param, ctx):
         if isinstance(value, dict):
             return value
@@ -95,6 +104,10 @@ class Endpoints(click.ParamType):
             # pequod login -d http(s)://{domain}.pequod.example.org
             for service, domain in CORE_DOMAINS.items():
                 endpoints[service] = [h.format(service=service, domain=domain) for h in parts]
+        elif self.is_ip(parts[0]):
+            # pequod login -d fd7:123::1
+            for service, port in CORE_PORTS.items():
+                endpoints[service] = ['http://{}:{}/'.format(format_ip(ip), port) for ip in parts]
         else:
             # pequod login -d pequod.example.org
             # pequod login -d .pequod.example.org
